import React, { useCallback } from 'react';
import useAnimatedRef from '../hooks/useAnimatedRef.js';
import { mergeRefs } from './common.js';
const controlledAnimated = (props, forwardedRef) => {
    const { as: Tag = "div", animations, currentAnimation, onAnimationEnd, ...tagProps } = props;
    const animatedRef = useAnimatedRef(currentAnimation, animations, onAnimationEnd);
    const elementRef = useCallback(mergeRefs(forwardedRef, animatedRef), [forwardedRef]);
    return (React.createElement(Tag, { ref: elementRef, ...tagProps }));
};
/**
 * An Animated component that is controlled by the currentAnimation prop
 * The component may use a different HTML tag delegate via the `as` prop
 * May accept a ref to forward to the HTML tag delegate.
 * Note: forwarding a ref returned from {@link hooks.useAnimatedRef} may result in undeterministic behavior
 *
 * @typeParam A the accepted animation names
 * @typeParam T the HTML Tag delegate
 */
const ControlledAnimated = React.forwardRef(controlledAnimated);
controlledAnimated.displayName = "ControlledAnimated";
export default ControlledAnimated;
