import React, { useCallback } from "react";
import { mergeRefs } from './common.js';
import ControlledAnimated from './ControlledAnimated.js';
import useIsHovered from '../hooks/useIsHovered.js';
function hoverAnimated({ currentAnimation = null, ...rest }, ref) {
    const [hovered, hoverRef] = useIsHovered();
    const mergedRef = useCallback(mergeRefs(ref, hoverRef), [ref]);
    return (React.createElement(ControlledAnimated, { currentAnimation: currentAnimation || (hovered ? "hovering" : "notHovering"), ref: mergedRef, ...rest }));
}
;
/**
 * An Animated component that will track hover (via mouseenter/mouseleave listeners) and animate based on the corresponding hover state
 * May accept a ref to forward to the HTML tag delegate
 * May accept an overriding currentAnimation
 * @typeParam A additional animation names
 * @typeParam T the HTML Tag delegate
 */
const HoverAnimated = React.forwardRef(hoverAnimated);
hoverAnimated.displayName = "HoverAnimated";
export default HoverAnimated;
