/**
 * Helper to update a ref (either CallbackRef or RefObject) to the given next value
 */
export function setRef(ref, next) {
    if (ref) {
        if (typeof ref === 'function') {
            ref(next);
        }
        else {
            ref.current = next;
        }
    }
}
/**
 * Useful for tracking both a forwardedRef and a local ref
 *
 * If both refs are AnimatedRef, returns the first since AnimatedRefs should be unique
 *
 * @return a new ref that manages both given refs as one
 */
export function mergeRefs(ref1, ref2) {
    return (value) => {
        setRef(ref1, value);
        setRef(ref2, value);
    };
}
