import { useState } from 'react';
/**
 * Hook to use a QueuedTransitionState
 *
 * Useful for queuing state transitions while waiting for a concurrent event (like an animation completion) before updating state
 *
 * @param initialState
 * @returns QueuedTransitionState
 */
function useQueuedState(initialState) {
    const [queuedState, setQueuedState] = useState({
        current: initialState,
        actionQueue: [],
    });
    const transition = () => setQueuedState((prevState) => transitionNActions(prevState, 1));
    return {
        current: queuedState.current,
        enqueue: (newAction) => setQueuedState(({ current, actionQueue }) => ({
            current,
            actionQueue: [...actionQueue, newAction],
        })),
        transition,
        transitionAll: () => setQueuedState((prevState) => transitionNActions(prevState, prevState.actionQueue.length)),
    };
}
const transitionNActions = ({ current, actionQueue }, n) => {
    const next = actionQueue.slice(0, n).reduce((next, action) => dispatch(action, next), current);
    return { current: next, actionQueue: actionQueue.slice(n) };
};
const dispatch = (action, state) => (isFunctionAction(action) ? action(state) : action);
const isFunctionAction = (action) => typeof action === 'function';
export default useQueuedState;
