import { useCallback } from 'react';
import useTransitioningState from './useTransitioningState.js';
/**
 * Hook to use a boolean toggle state that supports asynchronous transitions
 *
 * Toggle transitions may be queued via startToggling, and all queued toggles are completed by endTransition
 *
 * @param initialState
 * @param initialTransitioning if true, will toggle away from initialState when the togglingElementRef is first set
 *
 * @return [isToggled, startToggling, endToggling, currentTransition]: TransitioningToggleState
 */
function useTransitioningToggle(initialState = false, initialTransitioning = false) {
    const [isToggled, startTransition, endTransition, isTransitioning] = useTransitioningState(initialState, initialTransitioning ? nextTransition(initialState) : null);
    const transition = nextTransition(isToggled);
    const startToggling = useCallback((isAsync = true) => startTransition((prev) => !prev, isAsync ? transition : null), [transition]);
    const currentTransition = isTransitioning !== null ? transition : null;
    return [isToggled, startToggling, endTransition, currentTransition];
}
const nextTransition = (isToggled) => (isToggled ? 'togglingOff' : 'togglingOn');
export default useTransitioningToggle;
